@@ -7,7 +7,7 @@ command = [
     'python3 -m pip install -r requirements.txt'
 ]
 print("Install dependents...")
-success = subprocess.run(command, stdout=subprocess.DEVNULL, shell=True)
+success = subprocess.run(command, shell=True)
 
 from discord_chatbot.runner import start_bot
 
